# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/operation/operation_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.operation import types_pb2 as t2iapi_dot_operation_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)t2iapi/operation/operation_requests.proto\x12\x10t2iapi.operation\x1a\x1ct2iapi/operation/types.proto\"b\n\x17SetOperatingModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x37\n\x0eoperating_mode\x18\x02 \x01(\x0e\x32\x1f.t2iapi.operation.OperatingModeB9\n$com.draeger.medical.t2iapi.operationB\x11OperationRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.operation.operation_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.draeger.medical.t2iapi.operationB\021OperationRequests'
  _SETOPERATINGMODEREQUEST._serialized_start=93
  _SETOPERATINGMODEREQUEST._serialized_end=191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/basic_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/basic_responses.proto\x12\x06t2iapi\x1a\x1bt2iapi/response_types.proto\"/\n\rBasicResponse\x12\x1e\n\x06result\x18\x01 \x01(\x0e\x32\x0e.t2iapi.ResultB,\n\x1a\x63om.draeger.medical.t2iapiB\x0e\x42\x61sicResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.basic_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\016BasicResponses'
  _BASICRESPONSE._serialized_start=69
  _BASICRESPONSE._serialized_end=116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18t2iapi/alert/types.proto\x12\x0ct2iapi.alert*\x92\x01\n\x13\x41lertSignalPresence\x12\x1c\n\x18\x41LERT_SIGNAL_PRESENCE_ON\x10\x00\x12\x1d\n\x19\x41LERT_SIGNAL_PRESENCE_OFF\x10\x01\x12\x1f\n\x1b\x41LERT_SIGNAL_PRESENCE_LATCH\x10\x02\x12\x1d\n\x19\x41LERT_SIGNAL_PRESENCE_ACK\x10\x03*\x87\x02\n\x1f\x41lertConditionEscalationProcess\x12\x37\n3ALERT_CONDITION_ESCALATION_PROCESS_START_ESCALATION\x10\x00\x12\x36\n2ALERT_CONDITION_ESCALATION_PROCESS_STOP_ESCALATION\x10\x01\x12\x39\n5ALERT_CONDITION_ESCALATION_PROCESS_START_DEESCALATION\x10\x02\x12\x38\n4ALERT_CONDITION_ESCALATION_PROCESS_STOP_DEESCALATION\x10\x03*y\n\x1c\x41larmSignalInactivationState\x12+\n\'ALARM_SIGNAL_INACTIVATION_STATE_ENABLED\x10\x00\x12,\n(ALARM_SIGNAL_INACTIVATION_STATE_DISABLED\x10\x01*_\n\x16\x41lertConditionPresence\x12!\n\x1d\x41LERT_CONDITION_PRESENCE_TRUE\x10\x00\x12\"\n\x1e\x41LERT_CONDITION_PRESENCE_FALSE\x10\x01\x42.\n com.draeger.medical.t2iapi.alertB\nAlertTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\nAlertTypes'
  _ALERTSIGNALPRESENCE._serialized_start=43
  _ALERTSIGNALPRESENCE._serialized_end=189
  _ALERTCONDITIONESCALATIONPROCESS._serialized_start=192
  _ALERTCONDITIONESCALATIONPROCESS._serialized_end=455
  _ALARMSIGNALINACTIVATIONSTATE._serialized_start=457
  _ALARMSIGNALINACTIVATIONSTATE._serialized_end=578
  _ALERTCONDITIONPRESENCE._serialized_start=580
  _ALERTCONDITIONPRESENCE._serialized_end=675
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.device import device_requests_pb2 as t2iapi_dot_device_dot_device__requests__pb2
from t2iapi.device import device_responses_pb2 as t2iapi_dot_device_dot_device__responses__pb2


class DeviceServiceStub(object):
    """
    Service to handle device manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetDeviceOperatingMode = channel.unary_unary(
                '/t2iapi.device.DeviceService/SetDeviceOperatingMode',
                request_serializer=t2iapi_dot_device_dot_device__requests__pb2.SetDeviceOperatingModeRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.ShutDownDevice = channel.unary_unary(
                '/t2iapi.device.DeviceService/ShutDownDevice',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.BootUpDevice = channel.unary_unary(
                '/t2iapi.device.DeviceService/BootUpDevice',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SendHello = channel.unary_unary(
                '/t2iapi.device.DeviceService/SendHello',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetClockDevice = channel.unary_unary(
                '/t2iapi.device.DeviceService/SetClockDevice',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetLanguage = channel.unary_unary(
                '/t2iapi.device.DeviceService/SetLanguage',
                request_serializer=t2iapi_dot_device_dot_device__requests__pb2.SetLanguageRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.GetRemovableDescriptorsOfClass = channel.unary_unary(
                '/t2iapi.device.DeviceService/GetRemovableDescriptorsOfClass',
                request_serializer=t2iapi_dot_device_dot_device__requests__pb2.GetRemovableDescriptorsOfClassRequest.SerializeToString,
                response_deserializer=t2iapi_dot_device_dot_device__responses__pb2.GetRemovableDescriptorsResponse.FromString,
                )
        self.RemoveDescriptor = channel.unary_unary(
                '/t2iapi.device.DeviceService/RemoveDescriptor',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.InsertDescriptor = channel.unary_unary(
                '/t2iapi.device.DeviceService/InsertDescriptor',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.ChangeMdibSequenceID = channel.unary_unary(
                '/t2iapi.device.DeviceService/ChangeMdibSequenceID',
                request_serializer=t2iapi_dot_device_dot_device__requests__pb2.ChangeMdibSequenceIdRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.InsertMdsDescriptor = channel.unary_unary(
                '/t2iapi.device.DeviceService/InsertMdsDescriptor',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_device_dot_device__responses__pb2.InsertMdsDescriptorResponse.FromString,
                )
        self.RemoveMdsDescriptor = channel.unary_unary(
                '/t2iapi.device.DeviceService/RemoveMdsDescriptor',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.TriggerDescriptorUpdate = channel.unary_unary(
                '/t2iapi.device.DeviceService/TriggerDescriptorUpdate',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.TriggerReport = channel.unary_unary(
                '/t2iapi.device.DeviceService/TriggerReport',
                request_serializer=t2iapi_dot_device_dot_device__requests__pb2.TriggerReportRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )


class DeviceServiceServicer(object):
    """
    Service to handle device manipulations.
    """

    def SetDeviceOperatingMode(self, request, context):
        """
        Switch the device into a specific operating mode.
        This manipulation shall result in a Mds having a specific MdsOperatingMode.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShutDownDevice(self, request, context):
        """
        Shutdown the device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BootUpDevice(self, request, context):
        """
        Boot up the device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendHello(self, request, context):
        """
        Announce the presence of the device in the network via a WS-Discovery Hello message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetClockDevice(self, request, context):
        """
        Adjust the clock of the device as if it were set manually by a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLanguage(self, request, context):
        """
        Set the device's (displayed) language to the given language.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRemovableDescriptorsOfClass(self, request, context):
        """
        Get all descriptor handles which can be removed and reinserted into the MDIB of the device
        and whose descriptors are of the given class.
        Includes handles which have been removed already and can be reinserted.
        Handles must stay the same once reinserted into the MDIB.

        Calling GetRemovableDescriptorsOfClass with descriptor_class = DESCRIPTOR_CLASS_ABSTRACT
        returns the unfiltered handles while other values for descriptor_class
        return only handles whose descriptors are of the given class.

        The unfiltered handles shall be representative of the devices capabilities
        to remove descriptors (at least one of every possible kind).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveDescriptor(self, request, context):
        """
        Remove a descriptor from the device MDIB.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertDescriptor(self, request, context):
        """
        Insert a descriptor into the device MDIB.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeMdibSequenceID(self, request, context):
        """
        Change of the MDIB SequenceId.
        This manipulation of the device shall trigger a change of the MDIB SequenceId.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertMdsDescriptor(self, request, context):
        """
        Insert an mds descriptor into the device MDIB.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveMdsDescriptor(self, request, context):
        """
        Remove an mds descriptor from the device MDIB.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerDescriptorUpdate(self, request, context):
        """
        Trigger a descriptor update for the provided handle.
        This manipulation of the device shall result in a msg:DescriptionModificationReport message with a report part with
        modification type upt.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerReport(self, request, context):
        """
        Trigger a report message of the provided type.
        This manipulation of the device shall result in an msg:AbstractReport message of the provided type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetDeviceOperatingMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDeviceOperatingMode,
                    request_deserializer=t2iapi_dot_device_dot_device__requests__pb2.SetDeviceOperatingModeRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'ShutDownDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.ShutDownDevice,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'BootUpDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.BootUpDevice,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SendHello': grpc.unary_unary_rpc_method_handler(
                    servicer.SendHello,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetClockDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.SetClockDevice,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetLanguage': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLanguage,
                    request_deserializer=t2iapi_dot_device_dot_device__requests__pb2.SetLanguageRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'GetRemovableDescriptorsOfClass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRemovableDescriptorsOfClass,
                    request_deserializer=t2iapi_dot_device_dot_device__requests__pb2.GetRemovableDescriptorsOfClassRequest.FromString,
                    response_serializer=t2iapi_dot_device_dot_device__responses__pb2.GetRemovableDescriptorsResponse.SerializeToString,
            ),
            'RemoveDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveDescriptor,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'InsertDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertDescriptor,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'ChangeMdibSequenceID': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeMdibSequenceID,
                    request_deserializer=t2iapi_dot_device_dot_device__requests__pb2.ChangeMdibSequenceIdRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'InsertMdsDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertMdsDescriptor,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_device_dot_device__responses__pb2.InsertMdsDescriptorResponse.SerializeToString,
            ),
            'RemoveMdsDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveMdsDescriptor,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'TriggerDescriptorUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerDescriptorUpdate,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'TriggerReport': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerReport,
                    request_deserializer=t2iapi_dot_device_dot_device__requests__pb2.TriggerReportRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.device.DeviceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceService(object):
    """
    Service to handle device manipulations.
    """

    @staticmethod
    def SetDeviceOperatingMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/SetDeviceOperatingMode',
            t2iapi_dot_device_dot_device__requests__pb2.SetDeviceOperatingModeRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShutDownDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/ShutDownDevice',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BootUpDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/BootUpDevice',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendHello(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/SendHello',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetClockDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/SetClockDevice',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetLanguage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/SetLanguage',
            t2iapi_dot_device_dot_device__requests__pb2.SetLanguageRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRemovableDescriptorsOfClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/GetRemovableDescriptorsOfClass',
            t2iapi_dot_device_dot_device__requests__pb2.GetRemovableDescriptorsOfClassRequest.SerializeToString,
            t2iapi_dot_device_dot_device__responses__pb2.GetRemovableDescriptorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/RemoveDescriptor',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/InsertDescriptor',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeMdibSequenceID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/ChangeMdibSequenceID',
            t2iapi_dot_device_dot_device__requests__pb2.ChangeMdibSequenceIdRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertMdsDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/InsertMdsDescriptor',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_device_dot_device__responses__pb2.InsertMdsDescriptorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveMdsDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/RemoveMdsDescriptor',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerDescriptorUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/TriggerDescriptorUpdate',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.device.DeviceService/TriggerReport',
            t2iapi_dot_device_dot_device__requests__pb2.TriggerReportRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/operation/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/operation/types.proto\x12\x10t2iapi.operation*j\n\rOperatingMode\x12\x1b\n\x17OPERATING_MODE_DISABLED\x10\x00\x12\x1a\n\x16OPERATING_MODE_ENABLED\x10\x01\x12 \n\x1cOPERATING_MODE_NOT_AVAILABLE\x10\x02\x42\x36\n$com.draeger.medical.t2iapi.operationB\x0eOperationTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.operation.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.draeger.medical.t2iapi.operationB\016OperationTypes'
  _OPERATINGMODE._serialized_start=50
  _OPERATINGMODE._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.activation_state import activation_state_requests_pb2 as t2iapi_dot_activation__state_dot_activation__state__requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%t2iapi/activation_state/service.proto\x12\x17t2iapi.activation_state\x1a\x1ct2iapi/basic_responses.proto\x1a\x37t2iapi/activation_state/activation_state_requests.proto2\xd1\x02\n\x16\x41\x63tivationStateService\x12_\n\x12SetAlertActivation\x12\x32.t2iapi.activation_state.SetAlertActivationRequest\x1a\x15.t2iapi.BasicResponse\x12g\n\x16SetComponentActivation\x12\x36.t2iapi.activation_state.SetComponentActivationRequest\x1a\x15.t2iapi.BasicResponse\x12m\n\x19SetSystemSignalActivation\x12\x39.t2iapi.activation_state.SetSystemSignalActivationRequest\x1a\x15.t2iapi.BasicResponseBH\n+com.draeger.medical.t2iapi.activation_stateB\x19\x41\x63tivationStateApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\031ActivationStateApiService'
  _ACTIVATIONSTATESERVICE._serialized_start=154
  _ACTIVATIONSTATESERVICE._serialized_end=491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/operation/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.operation import operation_requests_pb2 as t2iapi_dot_operation_dot_operation__requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1et2iapi/operation/service.proto\x12\x10t2iapi.operation\x1a\x1ct2iapi/basic_responses.proto\x1a)t2iapi/operation/operation_requests.proto2h\n\x10OperationService\x12T\n\x10SetOperatingMode\x12).t2iapi.operation.SetOperatingModeRequest\x1a\x15.t2iapi.BasicResponseB;\n$com.draeger.medical.t2iapi.operationB\x13OperationApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.operation.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.draeger.medical.t2iapi.operationB\023OperationApiService'
  _OPERATIONSERVICE._serialized_start=125
  _OPERATIONSERVICE._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.alert import alert_requests_pb2 as t2iapi_dot_alert_dot_alert__requests__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1at2iapi/alert/service.proto\x12\x0ct2iapi.alert\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a!t2iapi/alert/alert_requests.proto\x1a\x1bgoogle/protobuf/empty.proto2\xbe\x05\n\x0c\x41lertService\x12\x62\n\x19SetAlertConditionPresence\x12..t2iapi.alert.SetAlertConditionPresenceRequest\x1a\x15.t2iapi.BasicResponse\x12\\\n\x16SetAlertSignalPresence\x12+.t2iapi.alert.SetAlertSignalPresenceRequest\x1a\x15.t2iapi.BasicResponse\x12>\n\rSetAudioPause\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12\x41\n\x10\x43\x61ncelAudioPause\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12`\n\x18\x41lertConditionEscalation\x12-.t2iapi.alert.AlertConditionEscalationRequest\x1a\x15.t2iapi.BasicResponse\x12n\n\x1fSetAlarmSignalInactivationState\x12\x34.t2iapi.alert.SetAlarmSignalInactivationStateRequest\x1a\x15.t2iapi.BasicResponse\x12P\n\x1bSetAlertSystemNotFunctional\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x45\n\x10InitiateAlarmOff\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponseB3\n com.draeger.medical.t2iapi.alertB\x0f\x41lertApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\017AlertApiService'
  _ALERTSERVICE._serialized_start=168
  _ALERTSERVICE._serialized_end=870
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/alert/alert_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.alert import types_pb2 as t2iapi_dot_alert_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!t2iapi/alert/alert_requests.proto\x12\x0ct2iapi.alert\x1a\x18t2iapi/alert/types.proto\"D\n SetAlertConditionPresenceRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x10\n\x08presence\x18\x02 \x01(\x08\"d\n\x1dSetAlertSignalPresenceRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x33\n\x08presence\x18\x02 \x01(\x0e\x32!.t2iapi.alert.AlertSignalPresence\"t\n&SetAlarmSignalInactivationStateRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12:\n\x06\x65nable\x18\x02 \x01(\x0e\x32*.t2iapi.alert.AlarmSignalInactivationState\"|\n\x1f\x41lertConditionEscalationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12I\n\x12\x65scalation_process\x18\x02 \x01(\x0e\x32-.t2iapi.alert.AlertConditionEscalationProcessB1\n com.draeger.medical.t2iapi.alertB\rAlertRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.alert.alert_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.draeger.medical.t2iapi.alertB\rAlertRequests'
  _SETALERTCONDITIONPRESENCEREQUEST._serialized_start=77
  _SETALERTCONDITIONPRESENCEREQUEST._serialized_end=145
  _SETALERTSIGNALPRESENCEREQUEST._serialized_start=147
  _SETALERTSIGNALPRESENCEREQUEST._serialized_end=247
  _SETALARMSIGNALINACTIVATIONSTATEREQUEST._serialized_start=249
  _SETALARMSIGNALINACTIVATIONSTATEREQUEST._serialized_end=365
  _ALERTCONDITIONESCALATIONREQUEST._serialized_start=367
  _ALERTCONDITIONESCALATIONREQUEST._serialized_end=491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/basic_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/basic_requests.proto\x12\x06t2iapi\"$\n\x12\x42\x61sicHandleRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\"0\n\x15RepeatedStringRequest\x12\x17\n\x0frepeated_string\x18\x01 \x03(\tB+\n\x1a\x63om.draeger.medical.t2iapiB\rBasicRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.basic_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\rBasicRequests'
  _BASICHANDLEREQUEST._serialized_start=39
  _BASICHANDLEREQUEST._serialized_end=75
  _REPEATEDSTRINGREQUEST._serialized_start=77
  _REPEATEDSTRINGREQUEST._serialized_end=125
# @@protoc_insertion_point(module_scope)
